
# Geomancy

```{include} ../README.md
:start-after: <!-- start intro -->
:end-before: <!-- end intro -->
```

```{include} ../README.md
:start-after: <!-- start example -->
:end-before: <!-- end example -->
```

## Features

```{include} ../README.md
:start-after: <!-- start features -->
:end-before: <!-- end features -->
```

```{toctree}
:hidden:

quickstart
usage/index
```
```{toctree}
:hidden:
:caption: About the Project
:maxdepth: 1

changelog
```
